@@ -98,13 +98,16 @@ gui.plot.single <- function(){
         showpath = FALSE
         dat <- gui.open.compositional()
         message("Plot background lines?\n",
-                "1 - QFL classification\n",
-                "2 - Dickinson's QFL diagram\n",
-                "3 - no lines")
+                "1 - descriptive QFL diagram\n",
+                "2 - Folk's classification\n",
+                "3 - Dickinson's QFL diagram\n",
+                "4 - no lines")
         response2 <- readline()
         if (response2 == '1'){
-            type <- "QFL"
+            type <- "QFL.descriptive"
         } else if (response2 == '2'){
+            type <- "QFL.folk"
+        } else if (response2 == '3'){
             type <- "QFL.dickinson"
         } else {
             type <- "empty"
@@ -357,8 +360,8 @@ gui.help <- function(){
         if (response == "1"){
             message("Formatting requirements of compositional data files:\n",
                     "---------------------------------------------------\n",
-                    "A compositional data file consists of a comma separated table ",
-                    "in which the rows correspond to samples and the columns to categories. ",
+                    "A compositional data file consists of a comma separated table\n",
+                    "in which the rows correspond to samples and the columns to categories.\n",
                     "For example:\n",
                     "sample,zr,tm,rt,TiOx,sph,ap,ep,gt,st,and,ky,sil,amp,cpx,opx\n",
                     "N1,1,1,0,0,0,1,10,24,2,0,0,0,1,163,1\n",
@@ -371,15 +374,15 @@ gui.help <- function(){
                     "N8,5,0,0,0,2,0,23,46,1,0,0,1,11,113,0\n",
                     "N9,10,2,0,0,9,0,26,80,2,0,0,0,18,56,0\n",
                     "N10,2,0,0,0,4,0,16,28,2,0,1,0,34,126,0\n",
-                    "If you want to use the Minsorting function and SRD correction, ",
-                    "it is important to make sure that the component labels are consistent with ",
+                    "If you want to use the Minsorting function and SRD correction,\n",
+                    "it is important to make sure that the component labels are consistent with\n",
                     "the densities table.\n")
         } else if (response == "2"){
             message("Formatting requirements for distributional data files:\n",
                     "-----------------------------------------------------\n",
-                    "A distributional data file consists of a comma separated table ",
-                    "in which the columns correspond to different samples, each of which ",
-                    "may contain a different number of single grain analyses. ",
+                    "A distributional data file consists of a comma separated table\n",
+                    "in which the columns correspond to different samples, each of which\n",
+                    "may contain a different number of single grain analyses.\n",
                     "For example:\n",
                     "N1,N2,N3,N4,N5,N6,N7,N8,N9,N10\n",
                     "645.4,2764.6,418.6,1228.4,1227,605.1,931.2,2440.3,2117.6,2727.2\n",
@@ -401,125 +404,125 @@ gui.help <- function(){
                     "489.4,,791.5,,1279.3,,1120.2,1767.5,,1157.1\n",
                     "744.5,,2160.2,,1386.9,,1989.2,,,811.5\n",
                     "1287.4,,1043.6,,1210.8,,1163.4,,,1554.9\n",
-                    "It is also possible (though optional) to specify the analytical ",
-                    "uncertainties of these measurements. They are stored in a separate ",
+                    "It is also possible (though optional) to specify the analytical\n",
+                    "uncertainties of these measurements. They are stored in a separate\n",
                     ".csv file with exactly the same format as the measurement as shown above.\n")
         } else if (response == "3"){
             message("Formatting requirements for mineral density files:\n",
                     "-------------------------------------------------\n",
-                    "The Minsorting function and SRD correction require a table of ",
-                    "mineral densities. The provenance package comes with a default table ",
-                    "but it is also possible to specify a different set of densities. It ",
-                    "is important that the labels used for the different components in this ",
-                    "table are consistent with the compositional data files used elsewhere. ",
+                    "The Minsorting function and SRD correction require a table of\n",
+                    "mineral densities. The provenance package comes with a default table\n",
+                    "but it is also possible to specify a different set of densities. It\n",
+                    "is important that the labels used for the different components in this\n",
+                    "table are consistent with the compositional data files used elsewhere.\n ",
                     "For example:\n",
-                    "Q,F,Lv,Ls,Lm,mica,opaques,zr,tm,rt,sph,ap,mon,oth,ep,gt,ctd,",
-                    "st,and,ky,sil,amp,px,ol\n",
-                    "2.65,2.61,2.6,2.65,2.75,2.4,5,4.65,3.15,4.25,3.5,3.2,5.15,3.5,3.45,4,",
-                    "3.6,3.75,3.15,3.6,3,3.2,3.3,3.35\n")
+                    "Q,F,Lv,Ls,Lm,mica,opaques,zr,tm,rt,sph,ap,\n",
+                    "mon,oth,ep,gt,ctd,st,and,ky,sil,amp,px,ol\n",
+                    "2.65,2.61,2.6,2.65,2.75,2.4,5,4.65,3.15,4.25,3.5,3.2,\n",
+                    "5.15,3.5,3.45,4,3.6,3.75,3.15,3.6,3,3.2,3.3,3.35\n")
         } else if (response == "4"){
             message("Sample size calculations:\n",
                     "------------------------\n",
-                    "On the most basic level, provenance analysis requires the geologist to ",
-                    "identify certain properties in a representative number of grains from ",
-                    "each sample. The question then arises how many grains constitute a ",
-                    "'representative' number of grains. The answer to this question depends ",
-                    "on the geological problem of interest. The sample size calculators implemented ",
-                    "in provenance() assume that we are interested in collecting at least one grain ",
-                    "from every fraction greater than f=1/N, where N is an integer denoting the ",
+                    "On the most basic level, provenance analysis requires the geologist to\n",
+                    "identify certain properties in a representative number of grains from\n",
+                    "each sample. The question then arises how many grains constitute a\n",
+                    "'representative' number of grains. The answer to this question depends\n",
+                    "on the geological problem of interest. The sample size calculators implemented\n",
+                    "in provenance() assume that we are interested in collecting at least one grain\n",
+                    "from every fraction greater than f=1/N, where N is an integer denoting the\n",
                     "number of fractions. Using simple combinatorics, it is possible to calculate:\n",
-                    "(a) the number of grains n required to ensure that all N fractions were sampled ",
+                    "(a) the number of grains n required to ensure that all N fractions were sampled\n",
                     "at least once with p% certainty.\n",
-                    "(b) the largest fraction f of which it is p% certain that all were sampled ",
+                    "(b) the largest fraction f of which it is p% certain that all were sampled\n",
                     "at least one out of n grains.\n",
-                    "(c) the likelihood that a sample of size n has missed at least one ",
+                    "(c) the likelihood that a sample of size n has missed at least one\n",
                     "fraction of size f.\n",
                     "\nCiteable references:\n",
-                    "Vermeesch, P., 2004. How many grains are needed for a provenance study? ",
+                    "Vermeesch, P., 2004. How many grains are needed for a provenance study?\n",
                     "Earth and Planetary Science Letters 224, 441-451.\n",
-                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for ",
-                    "statistical provenance analysis. Sedimentary Geology, ",
+                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for\n",
+                    "statistical provenance analysis. Sedimentary Geology,\n",
                     "doi:10.1016/j.sedgeo.2016.01.009.\n")
         } else if (response == "5"){
             message("Cumulative Age Distributions (CADs):\n",
                     "-----------------------------------\n",
-                    "The probability distribution of detrital zircon U-Pb ages or any other ",
-                    "distributional dataset may be estimated using histograms or kernel density ",
-                    "estimates (KDEs). For a sample of limited size, these estimates never exactly ",
-                    "agree with the true age distribution, but are smooth approximation thereof. ",
-                    "In contrast, the Cumulative Age Distribution (also known as the 'Empirical ",
-                    "Cumulative Distribution Function) is a method to visualise distributional ",
+                    "The probability distribution of detrital zircon U-Pb ages or any other\n",
+                    "distributional dataset may be estimated using histograms or kernel density\n",
+                    "estimates (KDEs). For a sample of limited size, these estimates never exactly\n",
+                    "agree with the true age distribution, but are smooth approximation thereof.\n",
+                    "In contrast, the Cumulative Age Distribution (also known as the 'Empirical\n",
+                    "Cumulative Distribution Function) is a method to visualise distributional\n",
                     "datasets without the need for any smoothing.\n",
                     "\nCiteable references:\n",
-                    "Vermeesch, P., 2007. Quantitative geomorphology of the White Mountains ",
-                    "(California) using detrital apatite fission track thermochronology. ",
+                    "Vermeesch, P., 2007. Quantitative geomorphology of the White Mountains\n",
+                    "(California) using detrital apatite fission track thermochronology.\n",
                     "Journal of Geophysical Research (Earth Surface) 112, 3004. doi:10.1029/2006JF000671.\n",
-                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for ",
-                    "statistical provenance analysis. Sedimentary Geology, ",
+                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for\n",
+                    "statistical provenance analysis. Sedimentary Geology,\n",
                     "doi:10.1016/j.sedgeo.2016.01.009.\n")
         } else if (response == "6"){
             message("Kernel Density Estimation (KDE):\n",
                     "-------------------------------\n",
-                    "A large body of statistical literature has been written on the subject ",
-                    "of probability density estimation. The most widely used tools are the ",
-                    "traditional histogram, which is discrete and discontinuous, and the Kernel ",
-                    "Density Estimator (KDE), which is a smooth and continuous alternative. ",
-                    "A KDE is produced by arranging the measurements along a line and stacking ",
-                    "a so-called 'kernel' (typically a Gaussian bell curve) of a certain ",
-                    "width (the 'bandwidth') on top of each of them. Multiple samples can be ",
-                    "plotted together, either using automatically selected bandwidths using the ",
+                    "A large body of statistical literature has been written on the subject\n",
+                    "of probability density estimation. The most widely used tools are the\n",
+                    "traditional histogram, which is discrete and discontinuous, and the Kernel\n",
+                    "Density Estimator (KDE), which is a smooth and continuous alternative.\n",
+                    "A KDE is produced by arranging the measurements along a line and stacking\n",
+                    "a so-called 'kernel' (typically a Gaussian bell curve) of a certain\n",
+                    "width (the 'bandwidth') on top of each of them. Multiple samples can be\n",
+                    "plotted together, either using automatically selected bandwidths using the\n",
                     "algorithm of Botev et al. (2010), or any other value\n",
                     "\nCiteable references:\n",
-                    "Botev, Z. I., Grotowski, J. F., Kroese, D. P., 2010. Kernel density ",
+                    "Botev, Z. I., Grotowski, J. F., Kroese, D. P., 2010. Kernel density\n",
                     "estimation via diffusion. Annals of Statistics 38, 2916-2957.\n",
-                    "Vermeesch, P., 2012. On the visualisation of detrital age distributions. ",
+                    "Vermeesch, P., 2012. On the visualisation of detrital age distributions.\n",
                     "Chemical Geology 312-313, 190-194. doi:10.1016/j.chemgeo.2012.04.021.\n",
-                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for ",
-                    "statistical provenance analysis. Sedimentary Geology, ",
+                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for\n",
+                    "statistical provenance analysis. Sedimentary Geology,\n",
                     "doi:10.1016/j.sedgeo.2016.01.009.\n")
         } else if (response == "7"){
             message("Minsorting and SRD correction:\n",
                     "-----------------------------\n",
-                    "To facilitate the comparison of detrital modes for provenance analysis ",
-                    "or stratigraphic correlation, we need to first remove the often significant ",
-                    "compositional differences among sediment samples that are caused by ",
-                    "hydrodynamic processes in the depositional environment. Intersample modal ",
-                    "variability can be corrected for by a simple principle. In the absence of ",
-                    "provenance changes and environmental bias, the weighted average ",
-                    "Source Rock Density (SRD) of terrigenous grains should be equal, ",
-                    "for each sample and each grain-size class of each sample, to the ",
-                    "weighted average density of source rocks. By correcting relative ",
-                    "abundances of detrital minerals in proportion to their densities, ",
-                    "we can restore the appropriate SRD index for any provenance and ",
-                    "subprovenance type in each sample or grain-size class (Garzanti et al., 2009).",
-                    "Within a sample of a certain average grain size, the denser minerals will ",
-                    "tend to be enriched in the finer fraction, and the lighter minerals in the ",
-                    "coarser fraction. This so-called principle of 'settling equivalence' ",
-                    "(Garzanti et al., 2008), is implemented in the Minsorting function, which is ",
+                    "To facilitate the comparison of detrital modes for provenance analysis\n",
+                    "or stratigraphic correlation, we need to first remove the often significant\n",
+                    "compositional differences among sediment samples that are caused by\n",
+                    "hydrodynamic processes in the depositional environment. Intersample modal\n",
+                    "variability can be corrected for by a simple principle. In the absence of\n",
+                    "provenance changes and environmental bias, the weighted average\n",
+                    "Source Rock Density (SRD) of terrigenous grains should be equal,\n",
+                    "for each sample and each grain-size class of each sample, to the\n",
+                    "weighted average density of source rocks. By correcting relative\n",
+                    "abundances of detrital minerals in proportion to their densities,\n",
+                    "we can restore the appropriate SRD index for any provenance and\n",
+                    "subprovenance type in each sample or grain-size class (Garzanti et al., 2009).\n",
+                    "Within a sample of a certain average grain size, the denser minerals will\n",
+                    "tend to be enriched in the finer fraction, and the lighter minerals in the\n",
+                    "coarser fraction. This so-called principle of 'settling equivalence'\n",
+                    "(Garzanti et al., 2008), is implemented in the Minsorting function, which is\n",
                     "based on the Excel spreadsheet of Resentini et al. (2013).\n",
                     "\nCiteable references:\n",
-                    "Garzanti, E., Ando, S., Vezzoli, G., 2009. Grain-size dependence of ",
-                    "sediment composition andenvironmental bias in provenance studies. ",
+                    "Garzanti, E., Ando, S., Vezzoli, G., 2009. Grain-size dependence of\n",
+                    "sediment composition andenvironmental bias in provenance studies.\n",
                     "Earth and Planetary Science Letters 277, 422-432.\n",
-                    "Garzanti, E, Ando, S and Vezzoli, G. Settling equivalence of detrital ",
-                    "minerals and grain-size dependence of sediment composition. ",
+                    "Garzanti, E, Ando, S and Vezzoli, G. Settling equivalence of detrital\n",
+                    "minerals and grain-size dependence of sediment composition.\n",
                     "Earth and Planetary Science Letters 273.1 (2008): 138-151.\n",
-                    "Resentini, A., Malusa, M.G., Garzanti, E., 2013. MinSORTING: An Excel ",
-                    "worksheet for modelling mineral grain-size distribution in sediments, ",
-                    "with application to detrital geochronology and provenance studies. ",
+                    "Resentini, A., Malusa, M.G., Garzanti, E., 2013. MinSORTING: An Excel\n",
+                    "worksheet for modelling mineral grain-size distribution in sediments,\n",
+                    "with application to detrital geochronology and provenance studies.\n",
                     "Computers & Geosciences 59, 90-97.\n",
-                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for ",
-                    "statistical provenance analysis. Sedimentary Geology, ",
+                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for\n",
+                    "statistical provenance analysis. Sedimentary Geology,\n",
                     "doi:10.1016/j.sedgeo.2016.01.009.\n")
         } else if (response == "8"){
             message("Multidimensional Scaling:\n",
                     "------------------------\n",
-                    "An increasing number of provenance studies are based on not just a few ",
-                    "but many samples. The large datasets resulting from such studies call ",
-                    "for a dimension-reducing technique such as Multi-Dimensional Scaling (MDS). ",
-                    "Given a dissimilarity matrix (i.e., a table of pairwise distances), ",
-                    "MDS constructs a 'map' on which 'similar' samples cluster closely ",
-                    "together and 'dissimilar' samples plot far apart. provenance() implements ",
+                    "An increasing number of provenance studies are based on not just a few\n",
+                    "but many samples. The large datasets resulting from such studies call\n",
+                    "for a dimension-reducing technique such as Multi-Dimensional Scaling (MDS).\n",
+                    "Given a dissimilarity matrix (i.e., a table of pairwise distances),\n",
+                    "MDS constructs a 'map' on which 'similar' samples cluster closely\n",
+                    "together and 'dissimilar' samples plot far apart. provenance() implements\n",
                     "the following dissimilarity measures:\n",
                     "Compositional data:\n",
                     "(a) the Aitchison distance (all components are strictly positive)\n",
@@ -527,46 +530,46 @@ gui.help <- function(){
                     "Distributional data:\n",
                     "(c) the Kolmogorov-Smirnov distance\n",
                     "(d) the Sircombe-Hazelton distance\n",
-                    "All these dissimilarities can be fitted using a 'non-metric' MDS ",
-                    "algorithm, which aims to preserve the rank order of the relative distances.",
-                    "For dissimilarities (a) and (c), it is also possible to perform ",
-                    "'classical MDS', which aims to represent the actual values of the dissimilarities",
-                    "Finally, for the Aitchison distance (a) which turns out to be a Euclidean ",
-                    "distance, it can be shown that MDS is equivalent to Principal Component Analysis ",
-                    "(PCA), in which the configuration can be plotted as a 'compositional biplot', ",
+                    "All these dissimilarities can be fitted using a 'non-metric' MDS\n",
+                    "algorithm, which aims to preserve the rank order of the relative distances.\n",
+                    "For dissimilarities (a) and (c), it is also possible to perform\n",
+                    "'classical MDS', which aims to represent the actual values of the dissimilarities\n",
+                    "Finally, for the Aitchison distance (a) which turns out to be a Euclidean\n",
+                    "distance, it can be shown that MDS is equivalent to Principal Component Analysis\n",
+                    "(PCA), in which the configuration can be plotted as a 'compositional biplot',\n",
                     "providing insights into the genetic origin of the observed intersample variability\n",
                     "\nCiteable references:\n",
-                    "Vermeesch, P., 2013. Multi-sample comparison of detrital age distributions. ",
+                    "Vermeesch, P., 2013. Multi-sample comparison of detrital age distributions.\n",
                     "Chemical Geology 341, 140-146.\n",
-                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for ",
-                    "statistical provenance analysis. Sedimentary Geology, ",
+                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for\n",
+                    "statistical provenance analysis. Sedimentary Geology,\n",
                     "doi:10.1016/j.sedgeo.2016.01.009.\n")
         } else if (response == "9"){
             message("Procrustes analysis and 3-way MDS:\n",
                     "---------------------------------\n",
-                    "Procrustes analysis and 3-way MDS are simple yet powerful tools ",
-                    "to extract geological insights from large, multi-method provenance datasets. ",
-                    "Procrustes analysis is the process by which a combination of ",
-                    "shape-preserving transformations is used to match the shape of ",
-                    "one object with that of another. Generalised Procrustes Analysis ",
-                    "(GPA) is a generalisation of this procedure to multiple objects. ",
-                    "In a provenance context, GPA extracts a single 'consensus' view from ",
-                    "a collection of MDS configurations, by rotating, reflecting and scaling ",
-                    "them to minimise a least squares criterion. ",
-                    "As the name suggests, 3-way MDS is a generalisation of the MDS method from ",
-                    "two-to three-dimensional dissimilarity matrices. provenance() implements ",
-                    "the INdividual Differences SCALing (INDCAL) algorithm, which is the oldest ",
-                    "and still most widely used 3-way MDS algorithm (de Leeuw and Mair, 2009). ",
-                    "In contrast with 2-way MDS and GPA, INDSCAL produces not one but two ",
+                    "Procrustes analysis and 3-way MDS are simple yet powerful tools\n",
+                    "to extract geological insights from large, multi-method provenance datasets.\n",
+                    "Procrustes analysis is the process by which a combination of\n",
+                    "shape-preserving transformations is used to match the shape of\n",
+                    "one object with that of another. Generalised Procrustes Analysis\n",
+                    "(GPA) is a generalisation of this procedure to multiple objects.\n",
+                    "In a provenance context, GPA extracts a single 'consensus' view from\n",
+                    "a collection of MDS configurations, by rotating, reflecting and scaling\n",
+                    "them to minimise a least squares criterion.\n",
+                    "As the name suggests, 3-way MDS is a generalisation of the MDS method from\n",
+                    "two-to three-dimensional dissimilarity matrices. provenance() implements\n",
+                    "the INdividual Differences SCALing (INDCAL) algorithm, which is the oldest\n",
+                    "and still most widely used 3-way MDS algorithm (de Leeuw and Mair, 2009).\n",
+                    "In contrast with 2-way MDS and GPA, INDSCAL produces not one but two\n",
                     "pieces of graphical output: the 'group configuration' and the 'source weights'.\n",
                     "\nCiteable references:\n",
-                    "de Leeuw, J., Mair, P., 2009. Multidimensional scaling using majorization: ",
-                    "The R package smacof. Journal of Statistical Software 31, 1-30. ",
+                    "de Leeuw, J., Mair, P., 2009. Multidimensional scaling using majorization:\n",
+                    "The R package smacof. Journal of Statistical Software 31, 1-30.\n",
                     "URL: http://www.jstatsoft.org/v31/i03\n",
-                    "Vermeesch, P., Garzanti, E., 2015. Making geological sense of 'Big Data' ",
+                    "Vermeesch, P., Garzanti, E., 2015. Making geological sense of 'Big Data'\n",
                     "in sedimentary provenance analysis. Chemical Geology 409, 20-27.\n",
-                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for ",
-                    "statistical provenance analysis. Sedimentary Geology, ",
+                    "Vermeesch, P., Resentini, A. and Garzanti, E., 2016. An R package for\n",
+                    "statistical provenance analysis. Sedimentary Geology,\n",
                     "doi:10.1016/j.sedgeo.2016.01.009.\n"
                     )
         } else {
@@ -606,7 +609,6 @@ gui.open.distributional <- function(){
     fname <- file.choose()
     errorfile <- NA
     dat <- read.distributional(fname,errorfile)
-    dat$name <- utils::tail(unlist(strsplit(fname, "/|.csv")),1)
     while (TRUE){
         message("Options:\n",
                 "1 - Subset samples\n",
